@@ -370,9 +370,9 @@ col.w.v <- function(mat, w = NULL, bin.vars = NULL, na.rm = TRUE) {
         s <- colSums(w, na.rm = na.rm)
         w <- mat_div(w, s)
         if (non.bin.vars.present) {
-            x <- sqrt(w[, !bin.vars, drop = FALSE]) * center(mat[, !bin.vars, drop = FALSE],
-                                                             at = colSums(w[, !bin.vars, drop = FALSE] * mat[, !bin.vars, drop = FALSE], na.rm = na.rm))
-            var[!bin.vars] <- colSums(x*x, na.rm = na.rm)/(1 - colSums(w[, !bin.vars, drop = FALSE]^2, na.rm = na.rm))
+            x <- center(mat[, !bin.vars, drop = FALSE],
+                        at = colSums(w[, !bin.vars, drop = FALSE] * mat[, !bin.vars, drop = FALSE], na.rm = na.rm))
+            var[!bin.vars] <- colSums(w[, !bin.vars, drop = FALSE]*x*x, na.rm = na.rm)/(1 - colSums(w[, !bin.vars, drop = FALSE]^2, na.rm = na.rm))
         }
         if (bin.var.present) {
             means <- colSums(w[, bin.vars, drop = FALSE] * mat[, bin.vars, drop = FALSE], na.rm = na.rm)
@@ -383,9 +383,9 @@ col.w.v <- function(mat, w = NULL, bin.vars = NULL, na.rm = TRUE) {
         if (is_null(w)) w <- rep(1, nrow(mat))
         w <- w/sum(w)
         if (non.bin.vars.present) {
-            x <- sqrt(w) * center(mat[, !bin.vars, drop = FALSE],
+            x <- center(mat[, !bin.vars, drop = FALSE],
                                   at = colSums(w * mat[, !bin.vars, drop = FALSE], na.rm = na.rm))
-            var[!bin.vars] <- colSums(x*x, na.rm = na.rm)/(1 - sum(w^2))
+            var[!bin.vars] <- colSums(w*x*x, na.rm = na.rm)/(1 - sum(w^2))
         }
         if (bin.var.present) {
             means <- colSums(w * mat[, bin.vars, drop = FALSE], na.rm = na.rm)
@@ -780,7 +780,10 @@ all_the_same <- function(x, na.rm = TRUE) {
 }
 is_binary <- function(x, na.rm = TRUE) {
     if (na.rm && anyNA(x)) x <- na.rem(x)
-    !all_the_same(x) && all_the_same(x[x != x[1]])
+    #Only return TRUE if not a continuous number that happens to take 2 values
+    is_not_null(x) && 
+        (!is.numeric(x) || all(check_if_zero(round(x) - x))) && 
+        !all_the_same(x) && all_the_same(x[x != x[1]])
 }
 is_binary_col <- function(dat, na.rm = TRUE) {
     if (length(dim(dat)) != 2) stop("is_binary_col cannot be used with objects that don't have 2 dimensions.")
@@ -878,6 +881,9 @@ is_ <- function(x, types, stop = FALSE, arg.to = FALSE) {
     }
     return(it.is)
 }
+is_mat_like <- function(x) {
+    length(dim(x)) == 2
+}
 is_null <- function(x) length(x) == 0L
 is_not_null <- function(x) !is_null(x)
 if_null_then <- function(x1 = NULL, x2 = NULL, ...) {
@@ -919,7 +925,8 @@ probably.a.bug <- function() {
     #Partial in w/ charmatch. TRUE if x at all in table.
     !is.na(charmatch(x, table))
 }
-null_or_error <- function(x) {is_null(x) || any(class(x) == "try-error")}
+is_error <- function(x) {inherits(x, "try-error")}
+null_or_error <- function(x) {is_null(x) || is_error(x)}
 match_arg <- function(arg, choices, several.ok = FALSE) {
     #Replaces match.arg() but gives cleaner error message and processing
     #of arg.
@@ -1005,10 +1012,10 @@ has_method <- function(class, fun) {
     if (!is.character(fun) || length(fun) != 1) stop("'fun' must be a string of length 1.")
     if (!is.character(class)) stop("'class' must be a character vector.")
     
-    vapply(class, function(cl) fun %in% attr(methods(class = cl), "info")$generic, logical(1L))
+    vapply(class, function(cl) is_not_null(getS3method(fun, cl, optional = TRUE, envir = asNamespace(packageName()))), logical(1L))
 }
 
-#Not used cobalt; replaced with rlang
+#Not used in cobalt; replaced with rlang
 is.formula <- function(f, sides = NULL) {
     #Replaced by rlang::is_formula
     res <- inherits(f, "formula") && is.name(f[[1]]) && deparse1(f[[1]]) %in% c( '~', '!') &&
@@ -1018,4 +1025,3 @@ is.formula <- function(f, sides = NULL) {
     }
     return(res)
 }
-if (getRversion() < 3.6) str2expression <- function(text) parse(text=text, keep.source=FALSE)
\ No newline at end of file
